@@ -10,25 +10,28 @@ import binascii
 import six
 import libnacl
 
-# Import Cryptographic libs
-import warnings
-
-
 from ioflo.base.consoling import getConsole
 console = getConsole()
 
+# Import raet libs
+# pylint: disable=wildcard-import,unused-wildcard-import,redefined-builtin
+from .abiding import *  # import globals
+# pylint: enable=wildcard-import,unused-wildcard-import,redefined-builtin
 from . import encoding
 
+
 class CryptoError(Exception):
     """
     Base exception for all nacl related errors
     """
 
+
 class BadSignatureError(CryptoError):
     """
     Raised when the signature was forged or otherwise corrupt.
     """
 
+
 class EncryptedMessage(six.binary_type):
     """
     A bytes subclass that holds a messaged that has been encrypted by a
@@ -56,6 +59,7 @@ class EncryptedMessage(six.binary_type):
         """
         return self._ciphertext
 
+
 class StringFixer(object):
     '''
     Python 3 support
@@ -66,6 +70,7 @@ class StringFixer(object):
         else:
             return self.__bytes__()
 
+
 class PublicKey(encoding.Encodable, StringFixer, object):
     """
     The public key counterpart to an Curve25519 :class:`PrivateKey`
@@ -89,6 +94,7 @@ class PublicKey(encoding.Encodable, StringFixer, object):
     def __bytes__(self):
         return self._public_key
 
+
 class PrivateKey(encoding.Encodable, StringFixer, object):
     """
     Private key for decrypting messages using the Curve25519 algorithm.
@@ -132,6 +138,7 @@ class PrivateKey(encoding.Encodable, StringFixer, object):
         """
         return cls(libnacl.randombytes(PrivateKey.SIZE), encoder=encoding.RawEncoder)
 
+
 class Box(encoding.Encodable, StringFixer, object):
     """
     The Box class boxes and unboxes messages between a pair of keys
@@ -240,6 +247,7 @@ class Box(encoding.Encodable, StringFixer, object):
 
         return plaintext
 
+
 class SignedMessage(six.binary_type):
     """
     A bytes subclass that holds a messaged that has been signed by a
@@ -391,7 +399,7 @@ class Signer(object):
     '''
     def __init__(self, key=None):
         if key:
-            if not isinstance(key, SigningKey): #not key so seed to regenerate
+            if not isinstance(key, SigningKey):  # not key so seed to regenerate
                 if len(key) == 32:
                     key = SigningKey(seed=key, encoder=encoding.RawEncoder)
                 else:
@@ -399,8 +407,8 @@ class Signer(object):
         else:
             key = SigningKey.generate()
         self.key = key
-        self.keyhex = self.key.encode(encoding.HexEncoder) #seed
-        self.keyraw = self.key.encode(encoding.RawEncoder) #seed
+        self.keyhex = self.key.encode(encoding.HexEncoder)  # seed
+        self.keyraw = self.key.encode(encoding.RawEncoder)  # seed
         self.verhex = self.key.verify_key.encode(encoding.HexEncoder)
         self.verraw = self.key.verify_key.encode(encoding.RawEncoder)
 
@@ -416,6 +424,7 @@ class Signer(object):
         '''
         return self.key.sign(msg).signature
 
+
 class Verifier(object):
     '''
     Used to verify messages with nacl digital signature
@@ -447,6 +456,7 @@ class Verifier(object):
             return False
         return True
 
+
 class Publican(object):
     '''
     Container to manage remote nacl public key
@@ -468,6 +478,7 @@ class Publican(object):
             self.keyhex = ''
             self.keyraw = ''
 
+
 class Privateer(object):
     '''
     Container for local nacl key pair
@@ -557,9 +568,9 @@ def uuid(size=16):
     '''
     size = max(int(size), 16)
     if sys.platform == 'win32':
-        front =  "{0:0x}".format(int(time.clock() * 1000000)) # microseconds
+        front = ns2b("{0:0x}".format(int(time.clock() * 1000000)))  # microseconds
     else:
-        front =  "{0:0x}".format(int(time.time() * 1000000)) # microseconds
+        front = ns2b("{0:0x}".format(int(time.time() * 1000000)))  # microseconds
     extra = size - len(front)
     back = binascii.hexlify(libnacl.randombytes(extra // 2 + extra % 2))
-    return ((front + back)[:size])
+    return ((front + back)[:size]).decode(encoding='ISO-8859-1')
